@@ -9,4 +9,4 @@ use Net::Nmsg::Output;
 my $n = Net::Nmsg::Input->open('127.0.0.1/8430');
 my $o = Net::Nmsg::Output->open_pres(\*STDOUT);
 
-$o->print while <$n>;
+$o->write while <$n>;
